@@ -2,11 +2,8 @@ use strict;
 use warnings;
 
 package Dist::Zilla::Plugin::ReadmeAnyFromPod;
-{
-  $Dist::Zilla::Plugin::ReadmeAnyFromPod::VERSION = '0.133060'; # TRIAL
-}
 # ABSTRACT: Automatically convert POD to a README in any format for Dist::Zilla
-
+$Dist::Zilla::Plugin::ReadmeAnyFromPod::VERSION = '0.142180'; # TRIAL
 use Encode qw( encode );
 use IO::Handle;
 use List::Util qw( reduce );
@@ -14,13 +11,11 @@ use Moose::Autobox;
 use Moose::Util::TypeConstraints qw(enum);
 use Moose;
 use MooseX::Has::Sugar;
-use PPI::Document;
-use PPI::Token::Pod;
-use Pod::Simple::HTML 3.23;
-use Pod::Simple::Text 3.23;
+use Path::Tiny 0.004;
 use Scalar::Util 'blessed';
 
 with 'Dist::Zilla::Role::AfterBuild';
+with 'Dist::Zilla::Role::AfterRelease';
 with 'Dist::Zilla::Role::FileGatherer';
 with 'Dist::Zilla::Role::FileMunger';
 with 'Dist::Zilla::Role::FilePruner';
@@ -38,6 +33,8 @@ our $_types = {
         parser => sub {
             my $pod = $_[0];
 
+            require Pod::Simple::Text;
+            Pod::Simple::Text->VERSION('3.23');
             my $parser = Pod::Simple::Text->new;
             $parser->output_string( \my $content );
             $parser->parse_characters(1);
@@ -66,6 +63,8 @@ our $_types = {
         parser => sub {
             my $pod = $_[0];
 
+            require Pod::Simple::HTML;
+            Pod::Simple::HTML->VERSION('3.23');
             my $parser = Pod::Simple::HTML->new;
             $parser->output_string( \my $content );
             $parser->parse_characters(1);
@@ -104,6 +103,21 @@ has location => (
 );
 
 
+has phase => (
+    ro, lazy,
+    isa => enum([qw(build release)]),
+    default => 'build',
+);
+
+
+sub BUILD {
+    my $self = shift;
+
+    $self->log_fatal('You cannot use location=build with phase=release!')
+        if $self->location eq 'build' and $self->phase eq 'release';
+}
+
+
 sub gather_files {
     my ($self) = @_;
 
@@ -190,6 +204,17 @@ sub munge_file {
 
 sub after_build {
     my $self = shift;
+    $self->_create_readme if $self->phase eq 'build';
+}
+
+
+sub after_release {
+    my $self = shift;
+    $self->_create_readme if $self->phase eq 'release';
+}
+
+sub _create_readme {
+    my $self = shift;
 
     if ( $self->location eq 'root' ) {
         my $filename = $self->filename;
@@ -197,7 +222,6 @@ sub after_build {
 
         my $content = $self->get_readme_content();
 
-        require Path::Tiny;
         my $file = $self->zilla->root->file($filename);
         if (-e $file) {
             $self->log("overriding $filename in root");
@@ -243,6 +267,8 @@ sub _get_source_pod {
     my ($self) = shift;
     my $source_content = $self->_get_source_content();
 
+    require PPI::Document;
+
     my $doc = PPI::Document->new(\$source_content);
     my $pod_elems = $doc->find('PPI::Token::Pod');
     my $pod_content = "";
@@ -306,7 +332,7 @@ Dist::Zilla::Plugin::ReadmeAnyFromPod - Automatically convert POD to a README in
 
 =head1 VERSION
 
-version 0.133060
+version 0.142180
 
 =head1 SYNOPSIS
 
@@ -354,6 +380,8 @@ build still works, but is less efficient).
 =head2 type
 
 The file format for the readme. Supported types are "text", "markdown", "pod", and "html".
+Note that you are not advised to create a F<.pod> file in the dist itself, as
+L<ExtUtils::MakeMaker> will install that, both into C<PERL5LIB> and C<MAN3DIR>.
 
 =head2 filename
 
@@ -383,6 +411,30 @@ built dist.
 
 =back
 
+If you want to generate the same README file in both the build
+directory and the root directory, simply generate it in the build
+directory and use the
+L<C<[CopyFilesFromBuild]>|Dist::Zilla::Plugin::CopyFilesFromBuild>
+plugin to copy it to the dist root.
+
+=head2 phase
+
+At what phase to generate the README file. Choices are:
+
+=over 4
+
+=item build
+
+(Default) This generates the README at 'after build' time.
+
+=item release
+
+This generates the README at 'after release' time. Note that this is too late
+to get the file into the generated tarball (C<location = build>), but ideal if
+you are using C<location = root>.
+
+=back
+
 =head1 METHODS
 
 =head2 gather_files
@@ -405,12 +457,23 @@ Edits the content into the requested README file in the dist.
 
 =head2 after_build
 
-Create the requested README file in the root.
+Create the requested README file at build time, if requested.
+
+=head2 after_release
+
+Create the requested README file at release time, if requested.
 
 =head2 get_readme_content
 
 Get the content of the README in the desired format.
 
+=for Pod::Coverage BUILD
+
+=head1 ACKNOWLEDGMENTS
+
+Thanks to Karen Etheridge (ETHER) for helping me maintain this module
+and keep it working through breaking changes in its dependencies.
+
 =head1 BUGS AND LIMITATIONS
 
 Please report any bugs or feature requests to
@@ -444,7 +507,7 @@ Ryan C. Thompson <rct@thompsonclan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ryan C. Thompson.
+This software is copyright (c) 2014 by Ryan C. Thompson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
